﻿using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;

namespace VolleyballGame
{

    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;

        private Texture2D background;


        private Player[] players = new Player[2];
        private Ball ball;

        private bool[] playerCollided = new[] { false, false };

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";

            players[0] = new Player(new Rectangle(5, 120, 390, 480), new Vector2(160, 220), false, Keys.W, Keys.S,
                                    Keys.A, Keys.D, this);

            players[1] = new Player(new Rectangle(405, 120, 390, 480), new Vector2(600, 220), true, Keys.Up, Keys.Down,
                                    Keys.Left, Keys.Right, this);

            Components.Add(players[0]);
            Components.Add(players[1]);


            ball = new Ball(new Rectangle(20, 20, 760, 580), new Vector2(400, 300), new Rectangle(395, 340, 10, 250), this);
            Components.Add(ball);
        }

        protected override void LoadContent()
        {
            spriteBatch = new SpriteBatch(GraphicsDevice);
            Services.AddService(typeof(SpriteBatch),spriteBatch);

            background = Content.Load<Texture2D>("background");
            
            base.LoadContent();

        }

        protected override void UnloadContent()
        {
            
        }

        protected override void Update(GameTime gameTime)
        {
            HandleCollisions();
            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {

            spriteBatch.Begin();

            spriteBatch.Draw(background, Vector2.Zero, Color.White);

            base.Draw(gameTime);
            spriteBatch.End();

        }

        private void HandleCollisions()
        {
            for (int i = 0; i < players.Length; i++)
            {
                Vector2 diff = (ball.Center - players[i].Center);
                if (diff.Length() < players[i].Radius + ball.Radius)
                {
                    if (!playerCollided[i])
                    {
                        Vector2 add = Vector2.Zero;

                        diff.Normalize();

                        if (0 < diff.X * players[i].Speed.X)
                            add.X = 3 * players[i].Speed.Length() * diff.X;

                        if (0 < diff.Y * players[i].Speed.Y)
                            add.Y = 3 * players[i].Speed.Length() * diff.Y;

                        ball.Bounce(diff, 1.1f, add);
                        playerCollided[i] = true;
                    }
                }
                else
                    playerCollided[i] = false;
            }
        }

    }
}
