using System;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;


namespace VolleyballGame
{
    public class Player : DrawableGameComponent
    {

        private static readonly Vector2 positionOffset = new Vector2(40, 40);
        private const float radius = 35;

        private static readonly Vector2 maxSpeed = new Vector2(6, 10),
                                        minSpeed = new Vector2(0.5f, 8),
                                        speedGain = new Vector2(1.45f, 0),
                                        speedFall = new Vector2(0.9f, 0),
                                        gravity = new Vector2(0, 0.2f);

        private static Texture2D texture;

        private Vector2 speed = Vector2.Zero;
        private Vector2 position;
        
        private Rectangle bounds;
        private Keys keyUp, keyDown, keyLeft, keyRight;
        private bool flip;




        public Player(Rectangle bounds, Vector2 position, bool flip, Keys keyUp,
                      Keys keyDown, Keys keyLeft, Keys keyRight, Game game)
            : base(game)
        {
            this.bounds = bounds;
            this.position = position;
            this.keyUp = keyUp;
            this.keyDown = keyDown;
            this.keyLeft = keyLeft;
            this.keyRight = keyRight;
            this.flip = flip;
        }

        protected override void LoadContent()
        {
            if (texture == null)
                texture = Game.Content.Load<Texture2D>("player");
            base.LoadContent();
        }

        public override void Update(GameTime gameTime)
        {
            if (Keyboard.GetState().IsKeyDown(keyLeft))
            {
                if (-speed.X < minSpeed.X)
                    speed.X = -minSpeed.X;
                else
                {
                    if (-speed.X < maxSpeed.X)
                        speed.X *= speedGain.X;

                    if (-speed.X > maxSpeed.X)
                        speed.X = -maxSpeed.X;
                }

            }
            else if (Keyboard.GetState().IsKeyDown(keyRight))
            {
                if (speed.X < minSpeed.X)
                    speed.X = minSpeed.X;
                else
                {
                    if (speed.X < maxSpeed.X)
                        speed.X *= speedGain.X;

                    if (speed.X > maxSpeed.X)
                        speed.X = maxSpeed.X;
                }
            }
            else
            {
                if (Math.Abs(speed.X) > minSpeed.X)
                    speed.X *= speedFall.X;
                else
                    speed.X = 0;
            }

            if (Keyboard.GetState().IsKeyDown(keyUp)
                && position.Y + texture.Height == bounds.Bottom)
            {
                speed.Y = -minSpeed.Y;
            }
            else
            {

                if (position.Y + texture.Height < bounds.Bottom)
                {
                    if (Keyboard.GetState().IsKeyDown(keyDown))
                        speed += 2 * gravity;
                    else
                        speed += gravity;
                }

                if (speed.Y > maxSpeed.Y)
                    speed.Y = maxSpeed.Y;
            }

            position += speed;

            if (position.X < bounds.Left)
                position.X = bounds.Left;
            else if (position.X + texture.Width > bounds.Right)
                position.X = bounds.Right - texture.Width;
            if (position.Y + texture.Height > bounds.Bottom)
            {
                position.Y = bounds.Bottom - texture.Height;
                speed.Y = 0;
            }
            else if (position.Y < bounds.Top)
                position.Y = bounds.Top;

            base.Update(gameTime);
        }

        public override void Draw(GameTime gameTime)
        {
            SpriteBatch spriteBatch = (SpriteBatch)Game.Services.GetService(typeof(SpriteBatch));

            if (!flip)
                spriteBatch.Draw(texture, position, null, Color.White, 0,
                            Vector2.Zero, 1, SpriteEffects.None, 0.5f);
            else
                spriteBatch.Draw(texture, position, null, Color.White, 0,
                            Vector2.Zero, 1, SpriteEffects.FlipHorizontally, 0.5f);

            base.Draw(gameTime);
        }

        protected override void UnloadContent()
        {
            texture.Dispose();
            base.UnloadContent();
        }

        public Vector2 Center
        {
            get { return position + positionOffset; }
        }

        public float Radius
        {
            get { return radius; }
        }

        public Vector2 Speed
        {
            get { return speed; }
        }

    }
}